from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoLqaProfileReferenceDto,
    QualityAssuranceRunDtoV3,
    UserReference,
    QualityAssuranceBatchRunDtoV3,
    LqaProfileDetailDto,
    UpdateIgnoredWarningsDto_2,
    LqaProfileReferenceDto,
    QualityAssuranceSegmentsRunDtoV3,
    InputStream,
    UpdateLqaProfileDto,
    QualityAssuranceResponseDto,
    QualityAssuranceChecksDtoV2,
    PageDtoUserReference,
    CreateLqaProfileDto,
    UpdateIgnoredChecksDto,
    UpdateIgnoredWarningsDto,
    QualityAssuranceChecksDtoV4
    
)


class QualityAssuranceOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def add_ignored_warnings(
        self,
        update_ignored_warnings_dto: UpdateIgnoredWarningsDto,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> UpdateIgnoredWarningsDto:
        """
        Operation id: addIgnoredWarnings
        Add ignored warnings
        
        :param update_ignored_warnings_dto: UpdateIgnoredWarningsDto (required), body. 
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UpdateIgnoredWarningsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/{job_uid}/qualityAssurances/ignoredWarnings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_ignored_warnings_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UpdateIgnoredWarningsDto(**r.json())
        


    async def add_ignored_warnings_v2(
        self,
        update_ignored_warnings_dto_2: UpdateIgnoredWarningsDto_2,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> UpdateIgnoredWarningsDto_2:
        """
        Operation id: addIgnoredWarningsV2
        Add ignored warnings
        
        :param update_ignored_warnings_dto_2: UpdateIgnoredWarningsDto_2 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UpdateIgnoredWarningsDto_2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/jobs/qualityAssurances/ignoredWarnings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_ignored_warnings_dto_2

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UpdateIgnoredWarningsDto_2(**r.json())
        


    async def create_lqa_profile(
        self,
        create_lqa_profile_dto: CreateLqaProfileDto,
        phrase_token: Optional[str] = None,
) -> LqaProfileDetailDto:
        """
        Operation id: createLqaProfile
        Create LQA profile
        
        :param create_lqa_profile_dto: CreateLqaProfileDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaProfileDetailDto
        """
        endpoint = f"/api2/v1/lqa/profiles"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_lqa_profile_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaProfileDetailDto(**r.json())
        


    async def delete_ignored_warnings(
        self,
        update_ignored_warnings_dto: UpdateIgnoredWarningsDto,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteIgnoredWarnings
        Delete ignored warnings
        
        :param update_ignored_warnings_dto: UpdateIgnoredWarningsDto (required), body. 
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/{job_uid}/qualityAssurances/ignoredWarnings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_ignored_warnings_dto

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_ignored_warnings_v2(
        self,
        update_ignored_warnings_dto_2: UpdateIgnoredWarningsDto_2,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteIgnoredWarningsV2
        Delete ignored warnings
        
        :param update_ignored_warnings_dto_2: UpdateIgnoredWarningsDto_2 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v2/projects/{project_uid}/jobs/qualityAssurances/ignoredWarnings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_ignored_warnings_dto_2

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_lqa_profile(
        self,
        profile_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteLqaProfile
        Delete LQA profile
        
        :param profile_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/lqa/profiles/{profile_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def duplicate_profile(
        self,
        profile_uid: str,
        phrase_token: Optional[str] = None,
) -> LqaProfileReferenceDto:
        """
        Operation id: duplicateProfile
        Duplicate LQA profile
        
        :param profile_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaProfileReferenceDto
        """
        endpoint = f"/api2/v1/lqa/profiles/{profile_uid}/duplicate"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaProfileReferenceDto(**r.json())
        


    async def enabled_quality_checks_for_job(
        self,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceChecksDtoV2:
        """
        Operation id: enabledQualityChecksForJob
        Get QA settings for job
        Returns enabled quality assurance checks and settings for job.
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceChecksDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/jobs/{job_uid}/qualityAssurances/settings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceChecksDtoV2(**r.json())
        


    async def enabled_quality_checks_for_project(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceChecksDtoV2:
        """
        Operation id: enabledQualityChecksForProject
        Get QA settings
        Returns enabled quality assurance checks and settings.
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceChecksDtoV2
        """
        endpoint = f"/api2/v2/projects/{project_uid}/jobs/qualityAssurances/settings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceChecksDtoV2(**r.json())
        


    async def get_lqa_profile(
        self,
        profile_uid: str,
        phrase_token: Optional[str] = None,
) -> LqaProfileDetailDto:
        """
        Operation id: getLqaProfile
        Get LQA profile details
        
        :param profile_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaProfileDetailDto
        """
        endpoint = f"/api2/v1/lqa/profiles/{profile_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaProfileDetailDto(**r.json())
        


    async def get_lqa_profile_authors(
        self,
        phrase_token: Optional[str] = None,
) -> UserReference:
        """
        Operation id: getLqaProfileAuthors
        Get list of LQA profile authors
        
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserReference
        """
        endpoint = f"/api2/v1/lqa/profiles/authors"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserReference(**r.json())
        


    async def get_lqa_profile_authors_v2(
        self,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 20,
        phrase_token: Optional[str] = None,
) -> PageDtoUserReference:
        """
        Operation id: getLqaProfileAuthorsV2
        Get list of LQA profile authors
        
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 20 (optional), query. Page size, accepts values between 1 and 50, default 20.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoUserReference
        """
        endpoint = f"/api2/v2/lqa/profiles/authors"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoUserReference(**r.json())
        


    async def get_lqa_profile_default_values(
        self,
        phrase_token: Optional[str] = None,
) -> LqaProfileDetailDto:
        """
        Operation id: getLqaProfileDefaultValues
        Get LQA profile default values
        
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaProfileDetailDto
        """
        endpoint = f"/api2/v1/lqa/profiles/defaultValues"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaProfileDetailDto(**r.json())
        


    async def get_lqa_profiles(
        self,
        created_by: Optional[str] = None,
        date_created: Optional[str] = None,
        name: Optional[str] = None,
        order: Optional[List[str]] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 20,
        sort: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoLqaProfileReferenceDto:
        """
        Operation id: getLqaProfiles
        GET list LQA profiles
        
        :param created_by: Optional[str] = None (optional), query. It is used for filter the list by who created the profile.
        :param date_created: Optional[str] = None (optional), query. It is used for filter the list by date created.
        :param name: Optional[str] = None (optional), query. Name of LQA profiles, it is used for filter the list by name.
        :param order: Optional[List[str]] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 20 (optional), query. Page size, accepts values between 1 and 50, default 20.
        :param sort: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoLqaProfileReferenceDto
        """
        endpoint = f"/api2/v1/lqa/profiles"
        params = {
            "name": name,
            "createdBy": created_by,
            "dateCreated": date_created,
            "pageNumber": page_number,
            "pageSize": page_size,
            "sort": sort,
            "order": order
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoLqaProfileReferenceDto(**r.json())
        


    async def get_qa_settings_for_job_part_v4(
        self,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceChecksDtoV4:
        """
        Operation id: getQaSettingsForJobPartV4
        Get QA settings for job part
        Returns enabled quality assurance checks and settings for job.
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceChecksDtoV4
        """
        endpoint = f"/api2/v4/projects/{project_uid}/jobs/{job_uid}/qualityAssurances/settings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceChecksDtoV4(**r.json())
        


    async def get_qa_settings_for_project_v4(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceChecksDtoV4:
        """
        Operation id: getQaSettingsForProjectV4
        Get QA settings for project
        Returns enabled quality assurance checks and settings.
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceChecksDtoV4
        """
        endpoint = f"/api2/v4/projects/{project_uid}/jobs/qualityAssurances/settings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceChecksDtoV4(**r.json())
        


    async def make_default(
        self,
        profile_uid: str,
        phrase_token: Optional[str] = None,
) -> LqaProfileReferenceDto:
        """
        Operation id: makeDefault
        Make LQA profile default
        
        :param profile_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaProfileReferenceDto
        """
        endpoint = f"/api2/v1/lqa/profiles/{profile_uid}/default"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaProfileReferenceDto(**r.json())
        


    async def run_qa_and_save_v4(
        self,
        input_stream: bytes,
        project_uid: str,
        segment_id: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaAndSaveV4
        Run quality assurance on selected segments and save segments
        By default runs only fast running checks.
        :param input_stream: bytes (required), body. 
        :param project_uid: str (required), path. 
        :param segment_id: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v4/projects/{project_uid}/jobs/qualityAssurances/segments/{segment_id}/runWithUpdate"
        params = {
            
        }
        headers = {
            
        }

        content = input_stream

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def run_qa_for_job_part_v3(
        self,
        quality_assurance_run_dto_v3: QualityAssuranceRunDtoV3,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaForJobPartV3
        Run quality assurance
        Call "Get QA settings" endpoint to get the list of enabled QA checks
        :param quality_assurance_run_dto_v3: QualityAssuranceRunDtoV3 (required), body. 
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v3/projects/{project_uid}/jobs/{job_uid}/qualityAssurances/run"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = quality_assurance_run_dto_v3

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def run_qa_for_job_part_v4(
        self,
        quality_assurance_run_dto_v3: QualityAssuranceRunDtoV3,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaForJobPartV4
        Run quality assurance
        Call "Get QA settings" endpoint to get the list of enabled QA checks
        :param quality_assurance_run_dto_v3: QualityAssuranceRunDtoV3 (required), body. 
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v4/projects/{project_uid}/jobs/{job_uid}/qualityAssurances/run"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = quality_assurance_run_dto_v3

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def run_qa_for_job_parts_v3(
        self,
        quality_assurance_batch_run_dto_v3: QualityAssuranceBatchRunDtoV3,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaForJobPartsV3
        Run quality assurance (batch)
        Call "Get QA settings" endpoint to get the list of enabled QA checks
        :param quality_assurance_batch_run_dto_v3: QualityAssuranceBatchRunDtoV3 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v3/projects/{project_uid}/jobs/qualityAssurances/run"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = quality_assurance_batch_run_dto_v3

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def run_qa_for_job_parts_v4(
        self,
        quality_assurance_batch_run_dto_v3: QualityAssuranceBatchRunDtoV3,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaForJobPartsV4
        Run quality assurance (batch)
        Call "Get QA settings" endpoint to get the list of enabled QA checks
        :param quality_assurance_batch_run_dto_v3: QualityAssuranceBatchRunDtoV3 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v4/projects/{project_uid}/jobs/qualityAssurances/run"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = quality_assurance_batch_run_dto_v3

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def run_qa_for_segments_v3(
        self,
        quality_assurance_segments_run_dto_v3: QualityAssuranceSegmentsRunDtoV3,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaForSegmentsV3
        Run quality assurance on selected segments
        By default runs only fast running checks. Source and target language of jobs have to match.
        :param quality_assurance_segments_run_dto_v3: QualityAssuranceSegmentsRunDtoV3 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v3/projects/{project_uid}/jobs/qualityAssurances/segments/run"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = quality_assurance_segments_run_dto_v3

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def run_qa_for_segments_v4(
        self,
        quality_assurance_segments_run_dto_v3: QualityAssuranceSegmentsRunDtoV3,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaForSegmentsV4
        Run quality assurance on selected segments
        By default runs only fast running checks. Source and target language of jobs have to match.
        :param quality_assurance_segments_run_dto_v3: QualityAssuranceSegmentsRunDtoV3 (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v4/projects/{project_uid}/jobs/qualityAssurances/segments/run"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = quality_assurance_segments_run_dto_v3

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def update_ignored_checks(
        self,
        update_ignored_checks_dto: UpdateIgnoredChecksDto,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: updateIgnoredChecks
        Edit ignored checks
        
        :param update_ignored_checks_dto: UpdateIgnoredChecksDto (required), body. 
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/{job_uid}/qualityAssurances/ignoreChecks"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_ignored_checks_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def update_lqa_profile(
        self,
        update_lqa_profile_dto: UpdateLqaProfileDto,
        profile_uid: str,
        phrase_token: Optional[str] = None,
) -> LqaProfileDetailDto:
        """
        Operation id: updateLqaProfile
        Update LQA profile
        
        :param update_lqa_profile_dto: UpdateLqaProfileDto (required), body. 
        :param profile_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: LqaProfileDetailDto
        """
        endpoint = f"/api2/v1/lqa/profiles/{profile_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_lqa_profile_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return LqaProfileDetailDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    ProjectJobPartsDto,
    InputStream,
    UploadBilingualFileRequestDto,
    ComparedSegmentsDto,
    GetBilingualFileDto,
    QualityAssuranceResponseDto
    
)


class BilingualFileOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def compare_bilingual_file(
        self,
        input_stream: bytes,
        workflow_level: Optional[int] = 1,
        phrase_token: Optional[str] = None,
) -> ComparedSegmentsDto:
        """
        Operation id: compareBilingualFile
        Compare bilingual file
        Compares bilingual file to job state. Returns list of compared segments.
        :param input_stream: bytes (required), body. 
        :param workflow_level: Optional[int] = 1 (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ComparedSegmentsDto
        """
        endpoint = f"/api2/v1/bilingualFiles/compare"
        params = {
            "workflowLevel": workflow_level
            
        }
        headers = {
            
        }

        content = input_stream

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ComparedSegmentsDto(**r.json())
        


    async def convert_bilingual_file(
        self,
        input_stream: bytes,
        frm: str,
        to: str,
        phrase_token: Optional[str] = None,
) -> bytes:
        """
        Operation id: convertBilingualFile
        Convert bilingual file
        
        :param input_stream: bytes (required), body. 
        :param frm: str (required), query. 
        :param to: str (required), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: bytes
        """
        endpoint = f"/api2/v1/bilingualFiles/convert"
        params = {
            "from": frm,
            "to": to
            
        }
        headers = {
            
        }

        content = input_stream

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return r.content
        


    async def get_bilingual_file(
        self,
        get_bilingual_file_dto: GetBilingualFileDto,
        project_uid: str,
        format: Optional[str] = "MXLF",
        preview: Optional[bool] = True,
        phrase_token: Optional[str] = None,
) -> bytes:
        """
        Operation id: getBilingualFile
        Download bilingual file
        
This API call generates a bilingual file in the chosen format by merging all submitted jobs together.
Note that all submitted jobs must belong to the same project; it's not feasible to merge jobs from multiple projects.

When dealing with MXLIFF or DOCX files, modifications made externally can be imported back into the Phrase TMS project.
Any changes will be synchronized into the editor, allowing actions like confirming or locking segments.

Unlike the user interface (UI), the APIs also support XLIFF as a bilingual format.

While MXLIFF files are editable using various means, their primary intended use is with the
[CAT Desktop Editor](https://support.phrase.com/hc/en-us/articles/5709683873052-CAT-Desktop-Editor-TMS-).
It's crucial to note that alterations to the file incompatible with the CAT Desktop Editor's features may result in
a corrupted file, leading to potential loss or duplication of work.

        :param get_bilingual_file_dto: GetBilingualFileDto (required), body. 
        :param project_uid: str (required), path. 
        :param format: Optional[str] = "MXLF" (optional), query. 
        :param preview: Optional[bool] = True (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: bytes
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/bilingualFile"
        params = {
            "format": format,
            "preview": preview
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = get_bilingual_file_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return r.content
        


    async def get_preview_file(
        self,
        input_stream: bytes,
        phrase_token: Optional[str] = None,
) -> bytes:
        """
        Operation id: getPreviewFile
        Download preview
        Supports mxliff format
        :param input_stream: bytes (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: bytes
        """
        endpoint = f"/api2/v1/bilingualFiles/preview"
        params = {
            
        }
        headers = {
            
        }

        content = input_stream

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return r.content
        


    async def run_qa_and_save_v4(
        self,
        input_stream: bytes,
        project_uid: str,
        segment_id: str,
        phrase_token: Optional[str] = None,
) -> QualityAssuranceResponseDto:
        """
        Operation id: runQaAndSaveV4
        Run quality assurance on selected segments and save segments
        By default runs only fast running checks.
        :param input_stream: bytes (required), body. 
        :param project_uid: str (required), path. 
        :param segment_id: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QualityAssuranceResponseDto
        """
        endpoint = f"/api2/v4/projects/{project_uid}/jobs/qualityAssurances/segments/{segment_id}/runWithUpdate"
        params = {
            
        }
        headers = {
            
        }

        content = input_stream

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QualityAssuranceResponseDto(**r.json())
        


    async def upload_bilingual_file_v2(
        self,
        multipart: UploadBilingualFileRequestDto,
        save_to_trans_memory: Optional[str] = "Confirmed",
        set_completed: Optional[bool] = False,
        phrase_token: Optional[str] = None,
) -> ProjectJobPartsDto:
        """
        Operation id: uploadBilingualFileV2
        Upload bilingual file
        Returns updated job parts and projects
        :param multipart: UploadBilingualFileRequestDto (required), body. Multipart request with files.
        :param save_to_trans_memory: Optional[str] = "Confirmed" (optional), query. 
        :param set_completed: Optional[bool] = False (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectJobPartsDto
        """
        endpoint = f"/api2/v2/bilingualFiles"
        params = {
            "saveToTransMemory": save_to_trans_memory,
            "setCompleted": set_completed
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = multipart

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectJobPartsDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    EditWorkflowStepDto,
    CreateWorkflowStepDto,
    PageDtoWorkflowStepDto,
    WorkflowStepDto,
    PageDtoWorkflowStepReference
    
)


class WorkflowStepOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def create_wf_step(
        self,
        create_workflow_step_dto: CreateWorkflowStepDto,
        phrase_token: Optional[str] = None,
) -> WorkflowStepDto:
        """
        Operation id: createWFStep
        Create workflow step
        
        :param create_workflow_step_dto: CreateWorkflowStepDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: WorkflowStepDto
        """
        endpoint = f"/api2/v1/workflowSteps"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_workflow_step_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return WorkflowStepDto(**r.json())
        


    async def delete_wf_step(
        self,
        workflow_step_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteWFStep
        Delete workflow step
        
        :param workflow_step_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/workflowSteps/{workflow_step_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def edit_wf_step(
        self,
        edit_workflow_step_dto: EditWorkflowStepDto,
        workflow_step_uid: str,
        phrase_token: Optional[str] = None,
) -> WorkflowStepDto:
        """
        Operation id: editWFStep
        Edit workflow step
        
        :param edit_workflow_step_dto: EditWorkflowStepDto (required), body. 
        :param workflow_step_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: WorkflowStepDto
        """
        endpoint = f"/api2/v1/workflowSteps/{workflow_step_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_workflow_step_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return WorkflowStepDto(**r.json())
        


    async def get_wf_step(
        self,
        workflow_step_uid: str,
        phrase_token: Optional[str] = None,
) -> WorkflowStepDto:
        """
        Operation id: getWFStep
        Get workflow step
        
        :param workflow_step_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: WorkflowStepDto
        """
        endpoint = f"/api2/v1/workflowSteps/{workflow_step_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return WorkflowStepDto(**r.json())
        


    async def list_wf_steps(
        self,
        abbr: Optional[str] = None,
        name: Optional[str] = None,
        order: Optional[str] = "ASC",
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        sort: Optional[str] = "ID",
        phrase_token: Optional[str] = None,
) -> PageDtoWorkflowStepDto:
        """
        Operation id: listWFSteps
        List workflow steps
        
        :param abbr: Optional[str] = None (optional), query. Abbreviation of workflow step.
        :param name: Optional[str] = None (optional), query. Name of the workflow step.
        :param order: Optional[str] = "ASC" (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param sort: Optional[str] = "ID" (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoWorkflowStepDto
        """
        endpoint = f"/api2/v1/workflowSteps"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "sort": sort,
            "order": order,
            "name": name,
            "abbr": abbr
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoWorkflowStepDto(**r.json())
        


    async def list_workflow_steps(
        self,
        user_uid: str,
        due_in_hours: Optional[int] = None,
        filename: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        project_uid: Optional[str] = None,
        status: Optional[List[str]] = None,
        target_lang: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoWorkflowStepReference:
        """
        Operation id: listWorkflowSteps
        List assigned workflow steps
        
        :param user_uid: str (required), path. 
        :param due_in_hours: Optional[int] = None (optional), query. -1 for jobs that are overdue.
        :param filename: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. 
        :param project_uid: Optional[str] = None (optional), query. 
        :param status: Optional[List[str]] = None (optional), query. 
        :param target_lang: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoWorkflowStepReference
        """
        endpoint = f"/api2/v1/users/{user_uid}/workflowSteps"
        params = {
            "status": status,
            "projectUid": project_uid,
            "targetLang": target_lang,
            "dueInHours": due_in_hours,
            "filename": filename,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoWorkflowStepReference(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from .phrase_tms_api_models import (
    ADMIN,
    ADMINEDIT,
    ADMINRESPONSE,
    AbsoluteTranslationLengthWarningDto,
    AbstractAnalyseSettingsDto,
    AbstractProjectDto,
    AbstractProjectDtoV2,
    AbstractUserCreateDto,
    AbstractUserEditDto,
    AccuracyWeightsDto,
    Action,
    Action1,
    AddCommentDto,
    AddLqaCommentResultDto,
    AddPlainCommentResultDto,
    AddTargetLangDto,
    AddWorkflowStepsDto,
    AdditionalWorkflowStepDto,
    AdditionalWorkflowStepRequestDto,
    AdditionalWorkflowStepV2Dto,
    AdminProjectManager,
    AdminProjectManagerV2,
    AllowedEntity,
    AnalyseJobDto,
    AnalyseJobReference,
    AnalyseLanguagePartDto,
    AnalyseLanguagePartReference,
    AnalyseLanguagePartV2Dto,
    AnalyseLanguagePartV3Dto,
    AnalyseRecalculateRequestDto,
    AnalyseRecalculateResponseDto,
    AnalyseReference,
    AnalyseSettingsDto,
    AnalyseV2Dto,
    AnalyseV3Dto,
    AnalysesV2Dto,
    AnalysisType_1,
    AnalysisType_2,
    AnalysisType_3,
    AndroidSettingsDto,
    AppleTokenResponseDto,
    AsciidocSettingsDto,
    AssessmentBasicDto,
    AssessmentDetailDto,
    AssessmentDetailsDto,
    AssessmentRequestDto,
    AssessmentResultDto,
    AssessmentResultsDto,
    AssignVendorDto,
    AssignableTemplatesDto,
    AssignedJobDto,
    AssignmentPerTargetLangDto,
    AsyncAnalyseListResponseDto,
    AsyncAnalyseListResponseV2Dto,
    AsyncAnalyseResponseDto,
    AsyncAnalyseResponseV2Dto,
    AsyncExportTMByQueryDto,
    AsyncExportTMByQueryResponseDto,
    AsyncExportTMDto,
    AsyncExportTMResponseDto,
    AsyncFileOpResponseDto,
    AsyncRequestDto,
    AsyncRequestReference,
    AsyncRequestReferenceDto,
    AsyncRequestStatusDto,
    AsyncRequestType,
    AsyncRequestV2Dto,
    AsyncRequestWrapperDto,
    AsyncRequestWrapperV2Dto,
    AsyncResponseDto,
    AsyncResponseV2Dto,
    Attribute,
    AttributeType,
    AuthSchema,
    AutomatedProjectSettingsDto,
    Availability,
    BackgroundTaskReference,
    BackgroundTasksTbDto,
    BackgroundTasksTmDto,
    BillingUnit,
    BillingUnit2,
    BrowseRequestDto,
    BrowseResponseListDto,
    BulkDeleteAnalyseDto,
    BulkDeleteTmDto,
    BulkEditAnalyseV2Dto,
    BusinessUnitDto,
    BusinessUnitEditDto,
    BusinessUnitReference,
    BusinessUnitReference2,
    BusinessUnitReference3,
    Buyer,
    BuyerDto,
    BuyerEditDto,
    BuyerReference,
    CellFlow,
    CheckResponse,
    CleanedTransMemoriesDto,
    CleanupTask,
    ClientDto,
    ClientEditDto,
    ClientReference,
    ClientReference2,
    ClientReference3,
    CloneProjectDto,
    CommentDto,
    CommonConversationDto,
    ComparedSegmentDto,
    ComparedSegmentsDto,
    ConceptDto,
    ConceptDtov2,
    ConceptEditDto,
    ConceptListReference,
    ConceptListResponseDto,
    ConceptWithMetadataDto,
    ConcurrentRequestsDto,
    ConnectorAsyncTaskStateDto,
    ConnectorAsyncTaskStatesDto,
    ConnectorDto,
    ConnectorErrorDetailDto,
    ConnectorErrorsDto,
    ConnectorListDto,
    ConnectorType,
    ContextKeySuffixType,
    ContextType,
    ContinuousJobInfoDto,
    ConversationListDto,
    CostCenterDto,
    CostCenterEditDto,
    CostCenterReference,
    CostCenterReference2,
    CountsDto,
    CountsDto2,
    CountsDto3,
    CreateAnalyseAsyncV2Dto,
    CreateAnalyseListAsyncDto,
    CreateCustomFieldDto,
    CreateCustomFieldInstanceDto,
    CreateCustomFieldInstancesDto,
    CreateCustomFileTypeDto,
    CreateLqaConversationDto,
    CreateLqaProfileDto,
    CreatePlainConversationDto,
    CreateProjectFromTemplateAsyncV2Dto,
    CreateProjectFromTemplateV2Dto,
    CreateProjectV3Dto,
    CreateReferenceFileNoteDto,
    CreateReferenceFilesRequest,
    CreateTermsDto,
    CreateVendorDto,
    CreateWebEditorLinkDtoV2,
    CreateWebHookDto,
    CreateWorkflowStepDto,
    CsvSettingsDto,
    CustomFieldDto,
    CustomFieldInstanceApiDto,
    CustomFieldInstanceApiV3Dto,
    CustomFieldInstanceDto,
    CustomFieldInstancesDto,
    CustomFieldOptionDto,
    CustomFieldOptionsTruncatedDto,
    CustomFileTypeDto,
    CustomFiletypeType,
    CustomQAWarningDto,
    CustomfieldType,
    DashboardSetting,
    DataDto,
    DataDto2,
    DataDtoV1,
    DeleteCustomFileTypeDto,
    DeleteVendorsDto,
    DelimiterType,
    DesignWeightsDto,
    DictionaryItemDto,
    Direction,
    DiscountSchemeCreateDto,
    DiscountSchemeReference,
    DiscountSchemeReference2,
    DiscountSettingsDto,
    DitaSettingsDto,
    DocBookSettingsDto,
    DocSettingsDto,
    DomainDto,
    DomainEditDto,
    DomainReference,
    DomainReference2,
    DomainReference3,
    DownloadTargetFileDto,
    EditAnalyseSettingsDto,
    EditAnalyseV2Dto,
    EditLqaConversationDto,
    EditPlainConversationDto,
    EditProjectMTSettPerLangDto,
    EditProjectMTSettPerLangListDto,
    EditProjectMTSettingsDto,
    EditProjectSecuritySettingsDtoV2,
    EditProjectV2Dto,
    EditProjectV3Dto,
    EditQASettingsDtoV2,
    EditSegmentationRuleDto,
    EditWorkflowStepDto,
    EditionDto,
    Email,
    EmailQuotesRequestDto,
    EmailQuotesResponseDto,
    EmailTemplateType,
    EmptyPairTagsWarningDto,
    EmptyTagContentWarningDto,
    EmptyTranslationWarningDto,
    EnabledCheck,
    EnabledCheckContextDtoV2,
    EnabledCheckContextDtoV4,
    EnabledCheckDtoV2,
    EnabledCheckDtoV4,
    EnabledQualityChecksDto,
    ErrorCategoriesDto,
    ErrorDetailDto,
    ErrorDetailDtoV2,
    ErrorDetailDtoV3,
    ErrorDto,
    ErrorsReference,
    Event,
    ExportByQueryDto,
    ExportTMDto,
    ExtraNumbersV3WarningDto,
    ExtraNumbersWarningDto,
    FeaturesDto,
    FileDto,
    FileFormat,
    FileHandoverDto,
    FileImportSettingsCreateDto,
    FileImportSettingsDto,
    FileListDto,
    FileNamingSettingsDto,
    Filter,
    FinancialSettingsDto,
    FindConversationsDto,
    FindConversationsForProjectDto,
    FinishAssessmentDto,
    FinishAssessmentItemDto,
    FinishAssessmentsDto,
    Flavor,
    FluencyWeightsDto,
    ForbiddenStringWarningDto,
    ForbiddenTermWarningDto,
    FormattingWarningDto,
    FuzzyInconsistencyWarningDto,
    GUEST,
    GUESTEDIT,
    GUESTRESPONSE,
    Gender,
    GetBilingualFileDto,
    GetFileRequestParamsDto,
    GlossaryActivationDto,
    GlossaryDto,
    GlossaryEditDto,
    GlossarySimpleDto,
    HtmlSettingsDto,
    HumanTranslateJobsDto,
    IdReference,
    IdmUserReference,
    IdmlSettingsDto,
    ImportSetSegmentConfirmedWhen,
    ImportSettingsCreateDto,
    ImportSettingsDto,
    ImportSettingsEditDto,
    ImportSettingsReference,
    ImportStatusDto,
    ImportStatusDtoV2,
    ImportTermBaseResponseDto,
    InconsistentTagContentWarningDto,
    InconsistentTranslationWarningDto,
    InputStream,
    InputStreamLength,
    IssueCountsDto,
    JobCreateRemoteFileDto,
    JobCreateRequestDto,
    JobExportActionDto,
    JobExportResponseDto,
    JobListDto,
    JobMachineTranslationSettingsV3Dto,
    JobNonTranslatableSettingsV3Dto,
    JobPartDeleteReferences,
    JobPartExtendedDto,
    JobPartPatchBatchDto,
    JobPartPatchResultDto,
    JobPartPatchSingleDto,
    JobPartReadyDeleteTranslationDto,
    JobPartReadyDeleteTranslationFilterDto,
    JobPartReadyReferences,
    JobPartReadyReferences2,
    JobPartReference,
    JobPartReferenceV2,
    JobPartReferences,
    JobPartSegmentsDtoV3,
    JobPartStatusChangeDto,
    JobPartStatusChangesDto,
    JobPartUpdateBatchDto,
    JobPartUpdateSingleDto,
    JobPartUpdateSourceDto,
    JobPartsDto,
    JobReference,
    JobRemoteFileReference,
    JobRoleDto,
    JobSegmentDto,
    JobStatusChangeActionDto,
    JobTranslationMemorySettingsV3Dto,
    JobUpdateSourceResponseDto,
    JobWidgetReference,
    JobroleType,
    JoinTagsWarningDto,
    JsonSettingsDto,
    LINGUIST,
    LINGUISTEDIT,
    LINGUISTRESPONSE,
    LQA,
    LQAConversationDto,
    LQAConversationsListDto,
    LQAReference,
    LQAReferences,
    LanguageDto2,
    LanguageListDto,
    LanguageMetadata,
    LanguageMetadata1,
    LastLoginDto,
    LeadingAndTrailingSpacesWarningDto,
    Level,
    Linguist,
    LinguistV2,
    LocaleConventionWeightsDto,
    LocaleFormat,
    LoginDto,
    LoginOtherDto,
    LoginOtherV3Dto,
    LoginResponseDto,
    LoginResponseV3Dto,
    LoginToSessionDto,
    LoginToSessionResponseDto,
    LoginToSessionResponseV3Dto,
    LoginToSessionV3Dto,
    LoginUserDto,
    LoginV3Dto,
    LoginWithAppleDto,
    LoginWithGoogleDto,
    LqaErrorCategoryDto,
    LqaProfileAssessmentDto,
    LqaProfileDetailDto,
    LqaProfileReferenceDto,
    LqaProfilesForWsV2Dto,
    LqaProfilesForWsV3Dto,
    LqaRecipientType,
    LqaReportEmailRequestDto,
    LqaReportLinkDto,
    LqaReportRecipientDto,
    LqaSettingsDto,
    LqaSeverityDto,
    MORAVIA,
    MTSettingsPerLanguageDto,
    MTSettingsPerLanguageListDto,
    MTSettingsPerLanguageReference,
    MacSettingsDto,
    MachineTranslateResponse,
    MachineTranslateSettingsDto,
    MachineTranslateSettingsLangsDto,
    MachineTranslateSettingsPbmDto,
    MachineTranslateSettingsReference,
    MachineTranslateSettingsSimpleDto,
    MachineTranslateStatusDto,
    MachineTranslationBehavior,
    MachineTranslationSettingsDto5,
    MalformedWarningDto,
    Match,
    MatchCounts101Dto,
    MatchCounts101Dto2,
    MatchCounts101Dto3,
    MatchCountsDto,
    MatchCountsDto2,
    MatchCountsDto3,
    MatchCountsNTDto,
    MatchCountsNTDto2,
    MatchCountsNTDtoV1,
    MdSettingsDto,
    MemTransMachineTranslateSettingsDto,
    MemsourceTranslateProfileDto,
    MemsourceTranslateProfileSimpleDto,
    MentionDto,
    MentionGroupType,
    MentionType,
    MentionableGroupDto,
    MentionableUserDto,
    MetadataField,
    MetadataOptionReference,
    MetadataPrioritySettingsDto,
    MetadataReference,
    MetadataResponse,
    MetadataResponse_2,
    MetadataTbDto,
    MetadataType,
    MifSettingsDto,
    MissingNonTranslatableAnnotationWarningDto,
    MissingNumbersV3WarningDto,
    MissingNumbersWarningDto,
    MisspelledWord,
    MisspelledWordDto,
    Mode,
    MoraviaWarningDto,
    MultilingualCsvSettingsDto,
    MultilingualXlsSettingsDto,
    MultilingualXmlSettingsDto,
    MultipartFile,
    MultipleSpacesV3WarningDto,
    MultipleSpacesWarningDto,
    Mutability,
    NUMBER,
    Name,
    NameDto,
    NestedTagsWarningDto,
    NetRateScheme,
    NetRateSchemeEdit,
    NetRateSchemeReference,
    NetRateSchemeWorkflowStep,
    NetRateSchemeWorkflowStepCreate,
    NetRateSchemeWorkflowStepEdit,
    NetRateSchemeWorkflowStepReference,
    NewerAtLowerLevelWarningDto,
    NonConformingTermWarningDto,
    NonEmptySegmentAction,
    NonTranslatableSettingsDto5,
    NotConfirmedWarningDto,
    NotificationDto,
    NotifyJobPartsRequestDto,
    NotifyProviderDto,
    Number,
    Number1,
    ObjectReference,
    Order,
    OrganizationEmailTemplateDto,
    OrganizationReference,
    OrganizationReference2,
    OrganizationType,
    Origin,
    Origin1,
    OtherWeightsDto,
    OutputFormat,
    PORTALMEMBER,
    PORTALMEMBEREDIT,
    PORTALMEMBERRESPONSE,
    PROJECTMANAGER,
    PROJECTMANAGEREDIT,
    PROJECTMANAGERRESPONSE,
    PageDtoAbstractProjectDto,
    PageDtoAdditionalWorkflowStepDto,
    PageDtoAnalyseJobDto,
    PageDtoAnalyseReference,
    PageDtoAssignedJobDto,
    PageDtoAsyncRequestDto,
    PageDtoBusinessUnitDto,
    PageDtoBuyerDto,
    PageDtoClientDto,
    PageDtoCommonConversationDto,
    PageDtoCostCenterDto,
    PageDtoCustomFieldDto,
    PageDtoCustomFieldInstanceDto,
    PageDtoCustomFieldOptionDto,
    PageDtoCustomFileTypeDto,
    PageDtoDomainDto,
    PageDtoGlossaryDto,
    PageDtoImportSettingsReference,
    PageDtoJobPartReferenceV2,
    PageDtoLastLoginDto,
    PageDtoLqaProfileReferenceDto,
    PageDtoLqaReportRecipientDto,
    PageDtoMachineTranslateSettingsPbmDto,
    PageDtoMemsourceTranslateProfileDto,
    PageDtoNetRateSchemeReference,
    PageDtoNetRateSchemeWorkflowStepReference,
    PageDtoOrganizationEmailTemplateDto,
    PageDtoProjectReference,
    PageDtoProjectTemplateReference,
    PageDtoProviderReference,
    PageDtoQuoteDto,
    PageDtoSegmentationRuleDto,
    PageDtoString,
    PageDtoSubDomainDto,
    PageDtoTermBaseDto,
    PageDtoTransMemoryDto,
    PageDtoTranslationPriceListDto,
    PageDtoTranslationPriceSetDto,
    PageDtoUploadedFileDto,
    PageDtoUserDto,
    PageDtoUserReference,
    PageDtoVendorDto,
    PageDtoWebHookDtoV2,
    PageDtoWebhookCallDto,
    PageDtoWorkflowStepDto,
    PageDtoWorkflowStepReference,
    PageDtoXmlAssistantProfileListDto,
    PageRequest,
    PageWithResponseTsDtoNotificationDto,
    PartOfSpeech,
    PassFailThresholdDto,
    PatchProjectDto,
    PdfSettingsDto,
    PenaltyPointsDto,
    PhpSettingsDto,
    PlainConversationDto,
    PlainConversationsListDto,
    PlainReferences,
    PoSettingsDto,
    Position,
    PostAnalyse,
    PptSettingsDto,
    PreAnalyse,
    PreAnalyseTargetCompare,
    PreTranslateJobSettingsV3Dto,
    PreTranslateJobsV3Dto,
    PreTranslateSettingsV4Dto,
    PreviewUrlDto,
    PreviewUrlType,
    PreviewUrlsDto,
    PreviousWorkflowDto,
    PriceListReference,
    ProgressDto,
    ProgressDtoV2,
    ProgressReference,
    ProjectJobPartsDto,
    ProjectMTSettingsPerLangDto,
    ProjectReference,
    ProjectReference2,
    ProjectReferenceFilesRequestDto,
    ProjectSecuritySettingsDtoV2,
    ProjectTemplate,
    ProjectTemplateCreateActionDto,
    ProjectTemplateDto,
    ProjectTemplateEditDto,
    ProjectTemplateEditV2Dto,
    ProjectTemplateNotifyProviderDto,
    ProjectTemplateReference,
    ProjectTemplateTermBaseDto,
    ProjectTemplateTermBaseListDto,
    ProjectTemplateTransMemoryDtoV3,
    ProjectTemplateTransMemoryListDtoV3,
    ProjectTemplateTransMemoryListV2Dto,
    ProjectTemplateTransMemoryV2Dto,
    ProjectTemplateWorkflowSettingsAssignedToDto,
    ProjectTemplateWorkflowSettingsDto,
    ProjectTermBaseDto,
    ProjectTermBaseListDto,
    ProjectTermBaseReference,
    ProjectTransMemoryDtoV3,
    ProjectTransMemoryListDtoV3,
    ProjectTranslationMemoryReference,
    ProjectWorkflowSettingsDto,
    ProjectWorkflowSettingsReference,
    ProjectWorkflowSettingsV2Dto,
    ProjectWorkflowStepDto,
    ProjectWorkflowStepDtoV2,
    ProjectWorkflowStepListDtoV2,
    ProjectWorkflowStepReference,
    PropertiesSettingsDto,
    ProviderListDtoV2,
    ProviderReference,
    ProviderReference2,
    Providers2,
    ProvidersPerLanguage,
    PsdSettingsDto,
    PseudoTranslateActionDto,
    PseudoTranslateActionDtoV2,
    PseudoTranslateWrapperDto,
    QACheckDtoV2,
    QASettingsDtoV2,
    QaCheckName,
    QaCheckType,
    QualityAssuranceBatchRunDtoV3,
    QualityAssuranceChecksDtoV2,
    QualityAssuranceChecksDtoV4,
    QualityAssuranceDto,
    QualityAssuranceResponseDto,
    QualityAssuranceRunDtoV3,
    QualityAssuranceSegmentsRunDtoV3,
    QuarkTagSettingsDto,
    Query,
    QuoteCreateV2Dto,
    QuoteDto,
    QuoteType,
    QuoteUnitsDto,
    QuoteV2Dto,
    QuoteWorkflowSettingDto,
    REGEX,
    ReferenceCorrelation,
    ReferenceFileAccessDto,
    ReferenceFilePageDto,
    ReferenceFileReference,
    ReferenceFilesDto,
    RegexpCheckRuleDtoV2,
    RegexpCheckRuleDtoV4,
    RelativeTranslationLengthWarningDto,
    RemoteUploadedFileDto,
    Repeated,
    RepeatedWordWarningDto,
    RepeatedWordsWarningDto,
    RepetitionsSettingsDto4,
    ReplayRequestDto,
    ResxSettingsDto,
    Returned,
    ReviewProviderDto,
    Role,
    Role4,
    Role5,
    RulesFormat,
    RunAutoLqaDto,
    SEGMENTTARGET,
    STRING,
    SUBMITTER,
    SUBMITTEREDIT,
    SUBMITTERRESPONSE,
    SchemaExtension,
    ScimMeta,
    ScimResourceSchema,
    ScimResourceTypeSchema,
    ScimUserCoreDto,
    ScoringResultDto,
    ScoringResultIssueCountsDto,
    SdlXlfSettingsDto,
    SearchInTextResponse2Dto,
    SearchInTextResponseList2Dto,
    SearchJobsDto,
    SearchJobsRequestDto,
    SearchRequestDto,
    SearchResponseListTbDto,
    SearchResponseListTmDto,
    SearchResponseListTmDtoV3,
    SearchResponseTbDto,
    SearchTMByJobRequestDto,
    SearchTMByJobRequestDtoV3,
    SearchTMClientDto,
    SearchTMClientDtoV3,
    SearchTMDomainDto,
    SearchTMDomainDtoV3,
    SearchTMProjectDto,
    SearchTMProjectDtoV3,
    SearchTMRequestDto,
    SearchTMResponseDto,
    SearchTMResponseDtoV3,
    SearchTMSegmentDto,
    SearchTMSegmentDtoV3,
    SearchTMSubDomainDto,
    SearchTMSubDomainDtoV3,
    SearchTMTransMemoryDto,
    SearchTMTransMemoryDtoV3,
    SearchTbByJobRequestDto,
    SearchTbInTextByJobRequestDto,
    SearchTbResponseDto,
    SearchTbResponseListDto,
    SecuritySettingsReference,
    SegRuleReference,
    SegmentDto,
    SegmentFilter,
    SegmentListDto,
    SegmentReference,
    SegmentWarningDto,
    SegmentWarningsDto,
    SegmentationRuleDto,
    SegmentationRulesOwnersDto,
    SegmentsCountsDto,
    SegmentsCountsResponseDto,
    SegmentsCountsResponseListDto,
    ServiceProviderConfigDto,
    SetContextPTTransMemoriesV2Dto,
    SetContextTransMemoriesDtoV3Dto,
    SetFinancialSettingsDto,
    SetProjectStatusDto,
    SetProjectTemplateTermBaseDto,
    SetProjectTemplateTransMemoriesV2Dto,
    SetProjectTemplateTransMemoryV2Dto,
    SetProjectTransMemoriesV3Dto,
    SetProjectTransMemoryV3Dto,
    SetTermBaseDto,
    SettingsReference,
    SeverityDto,
    Sort,
    SourceTargetRegexpWarningDto,
    SpellCheckRequestDto,
    SpellCheckResponseDto,
    SpellCheckWarningDto,
    SplitJobActionDto,
    State,
    Status,
    Status12,
    Status2,
    Status24,
    Status28,
    Status3,
    Status4,
    Status6,
    Status7,
    Status8,
    StatusDto,
    StyleWeightsDto,
    SubDomainDto,
    SubDomainEditDto,
    SubDomainReference,
    SubDomainReference2,
    SubDomainReference3,
    SubstituteDto,
    SubstituteDtoV2,
    SuggestRequestDto,
    SuggestResponse,
    SuggestResponseDto,
    Suggestion,
    Suggestion2,
    Supported,
    TMMatchSettingsDto,
    TagMetadata,
    TagMetadataDto,
    TargetFileWarningsDto,
    TargetLanguageDto,
    TargetSourceIdenticalWarningDto,
    TaskMappingDto,
    TaskProcessingType,
    TaskType,
    Term,
    TermBaseDto,
    TermBaseEditDto,
    TermBaseReference,
    TermBaseSearchRequestDto,
    TermCreateByJobDto,
    TermCreateDto,
    TermDto,
    TermEditDto,
    TermPairDto,
    TermType,
    TermV2Dto,
    TerminologyWarningDto,
    TerminologyWeightsDto,
    ToggleableWeightDto,
    TrailingPunctuationWarningDto,
    TrailingSpaceWarningDto,
    TransMemoryCreateDto,
    TransMemoryDto,
    TransMemoryDtoV2,
    TransMemoryDtoV3,
    TransMemoryEditDto,
    TransMemoryReferenceDtoV2,
    TranslationDto,
    TranslationLengthWarningDto,
    TranslationMemorySettingsDto5,
    TranslationPriceDto,
    TranslationPriceListCreateDto,
    TranslationPriceListDto,
    TranslationPriceSetBulkDeleteDto,
    TranslationPriceSetBulkMinimumPricesDto,
    TranslationPriceSetBulkPricesDto,
    TranslationPriceSetCreateDto,
    TranslationPriceSetDto,
    TranslationPriceSetListDto,
    TranslationRequestDto,
    TranslationRequestExtendedDto,
    TranslationResourcesDto,
    TranslationSegmentsReferenceV2,
    TtxSettingsDto,
    TxtSettingsDto,
    TypesDto,
    USER,
    UidReference,
    Uniqueness,
    UnmodifiedFuzzyTranslationMTNTWarningDto,
    UnmodifiedFuzzyTranslationTMWarningDto,
    UnmodifiedFuzzyTranslationWarningDto,
    UnresolvedCommentWarningDto,
    UnresolvedConversationWarningDto,
    UpdateCustomFieldInstanceDto,
    UpdateCustomFieldInstanceWithUidDto,
    UpdateCustomFieldInstancesDto,
    UpdateCustomFileTypeDto,
    UpdateIgnoredChecksDto,
    UpdateIgnoredJobPartSegment,
    UpdateIgnoredSegment,
    UpdateIgnoredSegment2,
    UpdateIgnoredWarning,
    UpdateIgnoredWarning2,
    UpdateIgnoredWarningsDto,
    UpdateIgnoredWarningsDto_2,
    UpdateLqaProfileDto,
    UploadBilingualFileRequestDto,
    UploadResultDto,
    UploadedFileDto,
    User,
    UserDetailsDtoV3,
    UserDto,
    UserPasswordEditDto,
    UserReference,
    UserReference2,
    UserReference3,
    UserReferencesDto,
    UserStatisticsDto,
    UserStatisticsListDto,
    VENDOR,
    VOID,
    Vendor,
    VendorDto,
    VendorReference,
    VendorSecuritySettingsDto,
    VendorUserReference,
    VerityWeightsDto,
    WebEditorLinkDtoV2,
    WebHookDtoV2,
    WebhookCallDto,
    WebhookPreviewDto,
    WebhookPreviewsDto,
    WildCardSearchByJobRequestDtoV3,
    WildCardSearchRequestDto,
    WorkflowChangesDto,
    WorkflowStepConfiguration,
    WorkflowStepDto,
    WorkflowStepReference,
    WorkflowStepReference2,
    WorkflowStepReferenceV2,
    WorkflowStepReferenceV3,
    WorkflowStepSettingsDto,
    WorkflowStepSettingsEditDto,
    WorkflowStepSettingsEditV2Dto,
    Xlf2SettingsDto,
    XlfSettingsDto,
    XlsSettingsDto,
    XmlAssistantProfileListDto,
    XmlSettingsDto,
    YamlSettingsDto
    )
from .header_json_models import (
    CreateSegmentationRuleMeta,
    JobUpdateSourceMeta,
    JobUpdateTargetMeta,
    RateLimitsBaseModel,
    UploadFileV2Meta,
    UploadHandoverFileMeta
    )
from .added_models import (
    UpdateCustomFieldDto
    )



all = [
    ADMIN,
    ADMINEDIT,
    ADMINRESPONSE,
    AbsoluteTranslationLengthWarningDto,
    AbstractAnalyseSettingsDto,
    AbstractProjectDto,
    AbstractProjectDtoV2,
    AbstractUserCreateDto,
    AbstractUserEditDto,
    AccuracyWeightsDto,
    Action,
    Action1,
    AddCommentDto,
    AddLqaCommentResultDto,
    AddPlainCommentResultDto,
    AddTargetLangDto,
    AddWorkflowStepsDto,
    AdditionalWorkflowStepDto,
    AdditionalWorkflowStepRequestDto,
    AdditionalWorkflowStepV2Dto,
    AdminProjectManager,
    AdminProjectManagerV2,
    AllowedEntity,
    AnalyseJobDto,
    AnalyseJobReference,
    AnalyseLanguagePartDto,
    AnalyseLanguagePartReference,
    AnalyseLanguagePartV2Dto,
    AnalyseLanguagePartV3Dto,
    AnalyseRecalculateRequestDto,
    AnalyseRecalculateResponseDto,
    AnalyseReference,
    AnalyseSettingsDto,
    AnalyseV2Dto,
    AnalyseV3Dto,
    AnalysesV2Dto,
    AnalysisType_1,
    AnalysisType_2,
    AnalysisType_3,
    AndroidSettingsDto,
    AppleTokenResponseDto,
    AsciidocSettingsDto,
    AssessmentBasicDto,
    AssessmentDetailDto,
    AssessmentDetailsDto,
    AssessmentRequestDto,
    AssessmentResultDto,
    AssessmentResultsDto,
    AssignVendorDto,
    AssignableTemplatesDto,
    AssignedJobDto,
    AssignmentPerTargetLangDto,
    AsyncAnalyseListResponseDto,
    AsyncAnalyseListResponseV2Dto,
    AsyncAnalyseResponseDto,
    AsyncAnalyseResponseV2Dto,
    AsyncExportTMByQueryDto,
    AsyncExportTMByQueryResponseDto,
    AsyncExportTMDto,
    AsyncExportTMResponseDto,
    AsyncFileOpResponseDto,
    AsyncRequestDto,
    AsyncRequestReference,
    AsyncRequestReferenceDto,
    AsyncRequestStatusDto,
    AsyncRequestType,
    AsyncRequestV2Dto,
    AsyncRequestWrapperDto,
    AsyncRequestWrapperV2Dto,
    AsyncResponseDto,
    AsyncResponseV2Dto,
    Attribute,
    AttributeType,
    AuthSchema,
    AutomatedProjectSettingsDto,
    Availability,
    BackgroundTaskReference,
    BackgroundTasksTbDto,
    BackgroundTasksTmDto,
    BillingUnit,
    BillingUnit2,
    BrowseRequestDto,
    BrowseResponseListDto,
    BulkDeleteAnalyseDto,
    BulkDeleteTmDto,
    BulkEditAnalyseV2Dto,
    BusinessUnitDto,
    BusinessUnitEditDto,
    BusinessUnitReference,
    BusinessUnitReference2,
    BusinessUnitReference3,
    Buyer,
    BuyerDto,
    BuyerEditDto,
    BuyerReference,
    CellFlow,
    CheckResponse,
    CleanedTransMemoriesDto,
    CleanupTask,
    ClientDto,
    ClientEditDto,
    ClientReference,
    ClientReference2,
    ClientReference3,
    CloneProjectDto,
    CommentDto,
    CommonConversationDto,
    ComparedSegmentDto,
    ComparedSegmentsDto,
    ConceptDto,
    ConceptDtov2,
    ConceptEditDto,
    ConceptListReference,
    ConceptListResponseDto,
    ConceptWithMetadataDto,
    ConcurrentRequestsDto,
    ConnectorAsyncTaskStateDto,
    ConnectorAsyncTaskStatesDto,
    ConnectorDto,
    ConnectorErrorDetailDto,
    ConnectorErrorsDto,
    ConnectorListDto,
    ConnectorType,
    ContextKeySuffixType,
    ContextType,
    ContinuousJobInfoDto,
    ConversationListDto,
    CostCenterDto,
    CostCenterEditDto,
    CostCenterReference,
    CostCenterReference2,
    CountsDto,
    CountsDto2,
    CountsDto3,
    CreateAnalyseAsyncV2Dto,
    CreateAnalyseListAsyncDto,
    CreateCustomFieldDto,
    CreateCustomFieldInstanceDto,
    CreateCustomFieldInstancesDto,
    CreateCustomFileTypeDto,
    CreateLqaConversationDto,
    CreateLqaProfileDto,
    CreatePlainConversationDto,
    CreateProjectFromTemplateAsyncV2Dto,
    CreateProjectFromTemplateV2Dto,
    CreateProjectV3Dto,
    CreateReferenceFileNoteDto,
    CreateReferenceFilesRequest,
    CreateTermsDto,
    CreateVendorDto,
    CreateWebEditorLinkDtoV2,
    CreateWebHookDto,
    CreateWorkflowStepDto,
    CsvSettingsDto,
    CustomFieldDto,
    CustomFieldInstanceApiDto,
    CustomFieldInstanceApiV3Dto,
    CustomFieldInstanceDto,
    CustomFieldInstancesDto,
    CustomFieldOptionDto,
    CustomFieldOptionsTruncatedDto,
    CustomFileTypeDto,
    CustomFiletypeType,
    CustomQAWarningDto,
    CustomfieldType,
    DashboardSetting,
    DataDto,
    DataDto2,
    DataDtoV1,
    DeleteCustomFileTypeDto,
    DeleteVendorsDto,
    DelimiterType,
    DesignWeightsDto,
    DictionaryItemDto,
    Direction,
    DiscountSchemeCreateDto,
    DiscountSchemeReference,
    DiscountSchemeReference2,
    DiscountSettingsDto,
    DitaSettingsDto,
    DocBookSettingsDto,
    DocSettingsDto,
    DomainDto,
    DomainEditDto,
    DomainReference,
    DomainReference2,
    DomainReference3,
    DownloadTargetFileDto,
    EditAnalyseSettingsDto,
    EditAnalyseV2Dto,
    EditLqaConversationDto,
    EditPlainConversationDto,
    EditProjectMTSettPerLangDto,
    EditProjectMTSettPerLangListDto,
    EditProjectMTSettingsDto,
    EditProjectSecuritySettingsDtoV2,
    EditProjectV2Dto,
    EditProjectV3Dto,
    EditQASettingsDtoV2,
    EditSegmentationRuleDto,
    EditWorkflowStepDto,
    EditionDto,
    Email,
    EmailQuotesRequestDto,
    EmailQuotesResponseDto,
    EmailTemplateType,
    EmptyPairTagsWarningDto,
    EmptyTagContentWarningDto,
    EmptyTranslationWarningDto,
    EnabledCheck,
    EnabledCheckContextDtoV2,
    EnabledCheckContextDtoV4,
    EnabledCheckDtoV2,
    EnabledCheckDtoV4,
    EnabledQualityChecksDto,
    ErrorCategoriesDto,
    ErrorDetailDto,
    ErrorDetailDtoV2,
    ErrorDetailDtoV3,
    ErrorDto,
    ErrorsReference,
    Event,
    ExportByQueryDto,
    ExportTMDto,
    ExtraNumbersV3WarningDto,
    ExtraNumbersWarningDto,
    FeaturesDto,
    FileDto,
    FileFormat,
    FileHandoverDto,
    FileImportSettingsCreateDto,
    FileImportSettingsDto,
    FileListDto,
    FileNamingSettingsDto,
    Filter,
    FinancialSettingsDto,
    FindConversationsDto,
    FindConversationsForProjectDto,
    FinishAssessmentDto,
    FinishAssessmentItemDto,
    FinishAssessmentsDto,
    Flavor,
    FluencyWeightsDto,
    ForbiddenStringWarningDto,
    ForbiddenTermWarningDto,
    FormattingWarningDto,
    FuzzyInconsistencyWarningDto,
    GUEST,
    GUESTEDIT,
    GUESTRESPONSE,
    Gender,
    GetBilingualFileDto,
    GetFileRequestParamsDto,
    GlossaryActivationDto,
    GlossaryDto,
    GlossaryEditDto,
    GlossarySimpleDto,
    HtmlSettingsDto,
    HumanTranslateJobsDto,
    IdReference,
    IdmUserReference,
    IdmlSettingsDto,
    ImportSetSegmentConfirmedWhen,
    ImportSettingsCreateDto,
    ImportSettingsDto,
    ImportSettingsEditDto,
    ImportSettingsReference,
    ImportStatusDto,
    ImportStatusDtoV2,
    ImportTermBaseResponseDto,
    InconsistentTagContentWarningDto,
    InconsistentTranslationWarningDto,
    InputStream,
    InputStreamLength,
    IssueCountsDto,
    JobCreateRemoteFileDto,
    JobCreateRequestDto,
    JobExportActionDto,
    JobExportResponseDto,
    JobListDto,
    JobMachineTranslationSettingsV3Dto,
    JobNonTranslatableSettingsV3Dto,
    JobPartDeleteReferences,
    JobPartExtendedDto,
    JobPartPatchBatchDto,
    JobPartPatchResultDto,
    JobPartPatchSingleDto,
    JobPartReadyDeleteTranslationDto,
    JobPartReadyDeleteTranslationFilterDto,
    JobPartReadyReferences,
    JobPartReadyReferences2,
    JobPartReference,
    JobPartReferenceV2,
    JobPartReferences,
    JobPartSegmentsDtoV3,
    JobPartStatusChangeDto,
    JobPartStatusChangesDto,
    JobPartUpdateBatchDto,
    JobPartUpdateSingleDto,
    JobPartUpdateSourceDto,
    JobPartsDto,
    JobReference,
    JobRemoteFileReference,
    JobRoleDto,
    JobSegmentDto,
    JobStatusChangeActionDto,
    JobTranslationMemorySettingsV3Dto,
    JobUpdateSourceResponseDto,
    JobWidgetReference,
    JobroleType,
    JoinTagsWarningDto,
    JsonSettingsDto,
    LINGUIST,
    LINGUISTEDIT,
    LINGUISTRESPONSE,
    LQA,
    LQAConversationDto,
    LQAConversationsListDto,
    LQAReference,
    LQAReferences,
    LanguageDto2,
    LanguageListDto,
    LanguageMetadata,
    LanguageMetadata1,
    LastLoginDto,
    LeadingAndTrailingSpacesWarningDto,
    Level,
    Linguist,
    LinguistV2,
    LocaleConventionWeightsDto,
    LocaleFormat,
    LoginDto,
    LoginOtherDto,
    LoginOtherV3Dto,
    LoginResponseDto,
    LoginResponseV3Dto,
    LoginToSessionDto,
    LoginToSessionResponseDto,
    LoginToSessionResponseV3Dto,
    LoginToSessionV3Dto,
    LoginUserDto,
    LoginV3Dto,
    LoginWithAppleDto,
    LoginWithGoogleDto,
    LqaErrorCategoryDto,
    LqaProfileAssessmentDto,
    LqaProfileDetailDto,
    LqaProfileReferenceDto,
    LqaProfilesForWsV2Dto,
    LqaProfilesForWsV3Dto,
    LqaRecipientType,
    LqaReportEmailRequestDto,
    LqaReportLinkDto,
    LqaReportRecipientDto,
    LqaSettingsDto,
    LqaSeverityDto,
    MORAVIA,
    MTSettingsPerLanguageDto,
    MTSettingsPerLanguageListDto,
    MTSettingsPerLanguageReference,
    MacSettingsDto,
    MachineTranslateResponse,
    MachineTranslateSettingsDto,
    MachineTranslateSettingsLangsDto,
    MachineTranslateSettingsPbmDto,
    MachineTranslateSettingsReference,
    MachineTranslateSettingsSimpleDto,
    MachineTranslateStatusDto,
    MachineTranslationBehavior,
    MachineTranslationSettingsDto5,
    MalformedWarningDto,
    Match,
    MatchCounts101Dto,
    MatchCounts101Dto2,
    MatchCounts101Dto3,
    MatchCountsDto,
    MatchCountsDto2,
    MatchCountsDto3,
    MatchCountsNTDto,
    MatchCountsNTDto2,
    MatchCountsNTDtoV1,
    MdSettingsDto,
    MemTransMachineTranslateSettingsDto,
    MemsourceTranslateProfileDto,
    MemsourceTranslateProfileSimpleDto,
    MentionDto,
    MentionGroupType,
    MentionType,
    MentionableGroupDto,
    MentionableUserDto,
    MetadataField,
    MetadataOptionReference,
    MetadataPrioritySettingsDto,
    MetadataReference,
    MetadataResponse,
    MetadataResponse_2,
    MetadataTbDto,
    MetadataType,
    MifSettingsDto,
    MissingNonTranslatableAnnotationWarningDto,
    MissingNumbersV3WarningDto,
    MissingNumbersWarningDto,
    MisspelledWord,
    MisspelledWordDto,
    Mode,
    MoraviaWarningDto,
    MultilingualCsvSettingsDto,
    MultilingualXlsSettingsDto,
    MultilingualXmlSettingsDto,
    MultipartFile,
    MultipleSpacesV3WarningDto,
    MultipleSpacesWarningDto,
    Mutability,
    NUMBER,
    Name,
    NameDto,
    NestedTagsWarningDto,
    NetRateScheme,
    NetRateSchemeEdit,
    NetRateSchemeReference,
    NetRateSchemeWorkflowStep,
    NetRateSchemeWorkflowStepCreate,
    NetRateSchemeWorkflowStepEdit,
    NetRateSchemeWorkflowStepReference,
    NewerAtLowerLevelWarningDto,
    NonConformingTermWarningDto,
    NonEmptySegmentAction,
    NonTranslatableSettingsDto5,
    NotConfirmedWarningDto,
    NotificationDto,
    NotifyJobPartsRequestDto,
    NotifyProviderDto,
    Number,
    Number1,
    ObjectReference,
    Order,
    OrganizationEmailTemplateDto,
    OrganizationReference,
    OrganizationReference2,
    OrganizationType,
    Origin,
    Origin1,
    OtherWeightsDto,
    OutputFormat,
    PORTALMEMBER,
    PORTALMEMBEREDIT,
    PORTALMEMBERRESPONSE,
    PROJECTMANAGER,
    PROJECTMANAGEREDIT,
    PROJECTMANAGERRESPONSE,
    PageDtoAbstractProjectDto,
    PageDtoAdditionalWorkflowStepDto,
    PageDtoAnalyseJobDto,
    PageDtoAnalyseReference,
    PageDtoAssignedJobDto,
    PageDtoAsyncRequestDto,
    PageDtoBusinessUnitDto,
    PageDtoBuyerDto,
    PageDtoClientDto,
    PageDtoCommonConversationDto,
    PageDtoCostCenterDto,
    PageDtoCustomFieldDto,
    PageDtoCustomFieldInstanceDto,
    PageDtoCustomFieldOptionDto,
    PageDtoCustomFileTypeDto,
    PageDtoDomainDto,
    PageDtoGlossaryDto,
    PageDtoImportSettingsReference,
    PageDtoJobPartReferenceV2,
    PageDtoLastLoginDto,
    PageDtoLqaProfileReferenceDto,
    PageDtoLqaReportRecipientDto,
    PageDtoMachineTranslateSettingsPbmDto,
    PageDtoMemsourceTranslateProfileDto,
    PageDtoNetRateSchemeReference,
    PageDtoNetRateSchemeWorkflowStepReference,
    PageDtoOrganizationEmailTemplateDto,
    PageDtoProjectReference,
    PageDtoProjectTemplateReference,
    PageDtoProviderReference,
    PageDtoQuoteDto,
    PageDtoSegmentationRuleDto,
    PageDtoString,
    PageDtoSubDomainDto,
    PageDtoTermBaseDto,
    PageDtoTransMemoryDto,
    PageDtoTranslationPriceListDto,
    PageDtoTranslationPriceSetDto,
    PageDtoUploadedFileDto,
    PageDtoUserDto,
    PageDtoUserReference,
    PageDtoVendorDto,
    PageDtoWebHookDtoV2,
    PageDtoWebhookCallDto,
    PageDtoWorkflowStepDto,
    PageDtoWorkflowStepReference,
    PageDtoXmlAssistantProfileListDto,
    PageRequest,
    PageWithResponseTsDtoNotificationDto,
    PartOfSpeech,
    PassFailThresholdDto,
    PatchProjectDto,
    PdfSettingsDto,
    PenaltyPointsDto,
    PhpSettingsDto,
    PlainConversationDto,
    PlainConversationsListDto,
    PlainReferences,
    PoSettingsDto,
    Position,
    PostAnalyse,
    PptSettingsDto,
    PreAnalyse,
    PreAnalyseTargetCompare,
    PreTranslateJobSettingsV3Dto,
    PreTranslateJobsV3Dto,
    PreTranslateSettingsV4Dto,
    PreviewUrlDto,
    PreviewUrlType,
    PreviewUrlsDto,
    PreviousWorkflowDto,
    PriceListReference,
    ProgressDto,
    ProgressDtoV2,
    ProgressReference,
    ProjectJobPartsDto,
    ProjectMTSettingsPerLangDto,
    ProjectReference,
    ProjectReference2,
    ProjectReferenceFilesRequestDto,
    ProjectSecuritySettingsDtoV2,
    ProjectTemplate,
    ProjectTemplateCreateActionDto,
    ProjectTemplateDto,
    ProjectTemplateEditDto,
    ProjectTemplateEditV2Dto,
    ProjectTemplateNotifyProviderDto,
    ProjectTemplateReference,
    ProjectTemplateTermBaseDto,
    ProjectTemplateTermBaseListDto,
    ProjectTemplateTransMemoryDtoV3,
    ProjectTemplateTransMemoryListDtoV3,
    ProjectTemplateTransMemoryListV2Dto,
    ProjectTemplateTransMemoryV2Dto,
    ProjectTemplateWorkflowSettingsAssignedToDto,
    ProjectTemplateWorkflowSettingsDto,
    ProjectTermBaseDto,
    ProjectTermBaseListDto,
    ProjectTermBaseReference,
    ProjectTransMemoryDtoV3,
    ProjectTransMemoryListDtoV3,
    ProjectTranslationMemoryReference,
    ProjectWorkflowSettingsDto,
    ProjectWorkflowSettingsReference,
    ProjectWorkflowSettingsV2Dto,
    ProjectWorkflowStepDto,
    ProjectWorkflowStepDtoV2,
    ProjectWorkflowStepListDtoV2,
    ProjectWorkflowStepReference,
    PropertiesSettingsDto,
    ProviderListDtoV2,
    ProviderReference,
    ProviderReference2,
    Providers2,
    ProvidersPerLanguage,
    PsdSettingsDto,
    PseudoTranslateActionDto,
    PseudoTranslateActionDtoV2,
    PseudoTranslateWrapperDto,
    QACheckDtoV2,
    QASettingsDtoV2,
    QaCheckName,
    QaCheckType,
    QualityAssuranceBatchRunDtoV3,
    QualityAssuranceChecksDtoV2,
    QualityAssuranceChecksDtoV4,
    QualityAssuranceDto,
    QualityAssuranceResponseDto,
    QualityAssuranceRunDtoV3,
    QualityAssuranceSegmentsRunDtoV3,
    QuarkTagSettingsDto,
    Query,
    QuoteCreateV2Dto,
    QuoteDto,
    QuoteType,
    QuoteUnitsDto,
    QuoteV2Dto,
    QuoteWorkflowSettingDto,
    REGEX,
    ReferenceCorrelation,
    ReferenceFileAccessDto,
    ReferenceFilePageDto,
    ReferenceFileReference,
    ReferenceFilesDto,
    RegexpCheckRuleDtoV2,
    RegexpCheckRuleDtoV4,
    RelativeTranslationLengthWarningDto,
    RemoteUploadedFileDto,
    Repeated,
    RepeatedWordWarningDto,
    RepeatedWordsWarningDto,
    RepetitionsSettingsDto4,
    ReplayRequestDto,
    ResxSettingsDto,
    Returned,
    ReviewProviderDto,
    Role,
    Role4,
    Role5,
    RulesFormat,
    RunAutoLqaDto,
    SEGMENTTARGET,
    STRING,
    SUBMITTER,
    SUBMITTEREDIT,
    SUBMITTERRESPONSE,
    SchemaExtension,
    ScimMeta,
    ScimResourceSchema,
    ScimResourceTypeSchema,
    ScimUserCoreDto,
    ScoringResultDto,
    ScoringResultIssueCountsDto,
    SdlXlfSettingsDto,
    SearchInTextResponse2Dto,
    SearchInTextResponseList2Dto,
    SearchJobsDto,
    SearchJobsRequestDto,
    SearchRequestDto,
    SearchResponseListTbDto,
    SearchResponseListTmDto,
    SearchResponseListTmDtoV3,
    SearchResponseTbDto,
    SearchTMByJobRequestDto,
    SearchTMByJobRequestDtoV3,
    SearchTMClientDto,
    SearchTMClientDtoV3,
    SearchTMDomainDto,
    SearchTMDomainDtoV3,
    SearchTMProjectDto,
    SearchTMProjectDtoV3,
    SearchTMRequestDto,
    SearchTMResponseDto,
    SearchTMResponseDtoV3,
    SearchTMSegmentDto,
    SearchTMSegmentDtoV3,
    SearchTMSubDomainDto,
    SearchTMSubDomainDtoV3,
    SearchTMTransMemoryDto,
    SearchTMTransMemoryDtoV3,
    SearchTbByJobRequestDto,
    SearchTbInTextByJobRequestDto,
    SearchTbResponseDto,
    SearchTbResponseListDto,
    SecuritySettingsReference,
    SegRuleReference,
    SegmentDto,
    SegmentFilter,
    SegmentListDto,
    SegmentReference,
    SegmentWarningDto,
    SegmentWarningsDto,
    SegmentationRuleDto,
    SegmentationRulesOwnersDto,
    SegmentsCountsDto,
    SegmentsCountsResponseDto,
    SegmentsCountsResponseListDto,
    ServiceProviderConfigDto,
    SetContextPTTransMemoriesV2Dto,
    SetContextTransMemoriesDtoV3Dto,
    SetFinancialSettingsDto,
    SetProjectStatusDto,
    SetProjectTemplateTermBaseDto,
    SetProjectTemplateTransMemoriesV2Dto,
    SetProjectTemplateTransMemoryV2Dto,
    SetProjectTransMemoriesV3Dto,
    SetProjectTransMemoryV3Dto,
    SetTermBaseDto,
    SettingsReference,
    SeverityDto,
    Sort,
    SourceTargetRegexpWarningDto,
    SpellCheckRequestDto,
    SpellCheckResponseDto,
    SpellCheckWarningDto,
    SplitJobActionDto,
    State,
    Status,
    Status12,
    Status2,
    Status24,
    Status28,
    Status3,
    Status4,
    Status6,
    Status7,
    Status8,
    StatusDto,
    StyleWeightsDto,
    SubDomainDto,
    SubDomainEditDto,
    SubDomainReference,
    SubDomainReference2,
    SubDomainReference3,
    SubstituteDto,
    SubstituteDtoV2,
    SuggestRequestDto,
    SuggestResponse,
    SuggestResponseDto,
    Suggestion,
    Suggestion2,
    Supported,
    TMMatchSettingsDto,
    TagMetadata,
    TagMetadataDto,
    TargetFileWarningsDto,
    TargetLanguageDto,
    TargetSourceIdenticalWarningDto,
    TaskMappingDto,
    TaskProcessingType,
    TaskType,
    Term,
    TermBaseDto,
    TermBaseEditDto,
    TermBaseReference,
    TermBaseSearchRequestDto,
    TermCreateByJobDto,
    TermCreateDto,
    TermDto,
    TermEditDto,
    TermPairDto,
    TermType,
    TermV2Dto,
    TerminologyWarningDto,
    TerminologyWeightsDto,
    ToggleableWeightDto,
    TrailingPunctuationWarningDto,
    TrailingSpaceWarningDto,
    TransMemoryCreateDto,
    TransMemoryDto,
    TransMemoryDtoV2,
    TransMemoryDtoV3,
    TransMemoryEditDto,
    TransMemoryReferenceDtoV2,
    TranslationDto,
    TranslationLengthWarningDto,
    TranslationMemorySettingsDto5,
    TranslationPriceDto,
    TranslationPriceListCreateDto,
    TranslationPriceListDto,
    TranslationPriceSetBulkDeleteDto,
    TranslationPriceSetBulkMinimumPricesDto,
    TranslationPriceSetBulkPricesDto,
    TranslationPriceSetCreateDto,
    TranslationPriceSetDto,
    TranslationPriceSetListDto,
    TranslationRequestDto,
    TranslationRequestExtendedDto,
    TranslationResourcesDto,
    TranslationSegmentsReferenceV2,
    TtxSettingsDto,
    TxtSettingsDto,
    TypesDto,
    USER,
    UidReference,
    Uniqueness,
    UnmodifiedFuzzyTranslationMTNTWarningDto,
    UnmodifiedFuzzyTranslationTMWarningDto,
    UnmodifiedFuzzyTranslationWarningDto,
    UnresolvedCommentWarningDto,
    UnresolvedConversationWarningDto,
    UpdateCustomFieldInstanceDto,
    UpdateCustomFieldInstanceWithUidDto,
    UpdateCustomFieldInstancesDto,
    UpdateCustomFileTypeDto,
    UpdateIgnoredChecksDto,
    UpdateIgnoredJobPartSegment,
    UpdateIgnoredSegment,
    UpdateIgnoredSegment2,
    UpdateIgnoredWarning,
    UpdateIgnoredWarning2,
    UpdateIgnoredWarningsDto,
    UpdateIgnoredWarningsDto_2,
    UpdateLqaProfileDto,
    UploadBilingualFileRequestDto,
    UploadResultDto,
    UploadedFileDto,
    User,
    UserDetailsDtoV3,
    UserDto,
    UserPasswordEditDto,
    UserReference,
    UserReference2,
    UserReference3,
    UserReferencesDto,
    UserStatisticsDto,
    UserStatisticsListDto,
    VENDOR,
    VOID,
    Vendor,
    VendorDto,
    VendorReference,
    VendorSecuritySettingsDto,
    VendorUserReference,
    VerityWeightsDto,
    WebEditorLinkDtoV2,
    WebHookDtoV2,
    WebhookCallDto,
    WebhookPreviewDto,
    WebhookPreviewsDto,
    WildCardSearchByJobRequestDtoV3,
    WildCardSearchRequestDto,
    WorkflowChangesDto,
    WorkflowStepConfiguration,
    WorkflowStepDto,
    WorkflowStepReference,
    WorkflowStepReference2,
    WorkflowStepReferenceV2,
    WorkflowStepReferenceV3,
    WorkflowStepSettingsDto,
    WorkflowStepSettingsEditDto,
    WorkflowStepSettingsEditV2Dto,
    Xlf2SettingsDto,
    XlfSettingsDto,
    XlsSettingsDto,
    XmlAssistantProfileListDto,
    XmlSettingsDto,
    YamlSettingsDto,
    CreateSegmentationRuleMeta,
    JobUpdateSourceMeta,
    JobUpdateTargetMeta,
    RateLimitsBaseModel,
    UploadFileV2Meta,
    UploadHandoverFileMeta,
    UpdateCustomFieldDto,
    
]


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    CreateReferenceFilesRequest,
    ProjectReferenceFilesRequestDto,
    ReferenceFilesDto,
    UserReferencesDto,
    ReferenceFilePageDto
    
)


class ProjectReferenceFileOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def batch_delete_reference_files(
        self,
        project_reference_files_request_dto: ProjectReferenceFilesRequestDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: batchDeleteReferenceFiles
        Delete project reference files (batch)
        
        :param project_reference_files_request_dto: ProjectReferenceFilesRequestDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projects/{project_uid}/references"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = project_reference_files_request_dto

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def batch_download_reference_files(
        self,
        project_reference_files_request_dto: ProjectReferenceFilesRequestDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> bytes:
        """
        Operation id: batchDownloadReferenceFiles
        Download project reference files (batch)
        
        :param project_reference_files_request_dto: ProjectReferenceFilesRequestDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: bytes
        """
        endpoint = f"/api2/v1/projects/{project_uid}/references/download"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = project_reference_files_request_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return r.content
        


    async def create_reference_files(
        self,
        multipart: CreateReferenceFilesRequest,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> ReferenceFilesDto:
        """
        Operation id: createReferenceFiles
        Create project reference files
        
The `json` request part allows sending additional data as JSON,
such as a text note that will be used for all the given reference files.
In case no `file` parts are sent, only 1 reference is created with the given note.
Either at least one file must be sent or the note must be specified.
Example:

```
{
    "note": "Sample text"
}
```

        :param multipart: CreateReferenceFilesRequest (required), body. Multipart request with files and JSON.
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ReferenceFilesDto
        """
        endpoint = f"/api2/v2/projects/{project_uid}/references"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = multipart

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ReferenceFilesDto(**r.json())
        


    async def download_reference(
        self,
        project_uid: str,
        reference_file_id: str,
        phrase_token: Optional[str] = None,
) -> bytes:
        """
        Operation id: downloadReference
        Download project reference file
        
        :param project_uid: str (required), path. 
        :param reference_file_id: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: bytes
        """
        endpoint = f"/api2/v1/projects/{project_uid}/references/{reference_file_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return r.content
        


    async def list_reference_file_creators(
        self,
        project_uid: str,
        user_name: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> UserReferencesDto:
        """
        Operation id: listReferenceFileCreators
        List project reference file creators
        The result is not paged and returns up to 50 users.
                If the requested user is not included, the search can be narrowed down with the `userName` parameter.
            
        :param project_uid: str (required), path. 
        :param user_name: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UserReferencesDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/references/creators"
        params = {
            "userName": user_name
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UserReferencesDto(**r.json())
        


    async def list_reference_files(
        self,
        project_uid: str,
        created_by: Optional[str] = None,
        date_created_since: Optional[str] = None,
        filename: Optional[str] = None,
        order: Optional[str] = "DESC",
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        sort: Optional[str] = "DATE_CREATED",
        phrase_token: Optional[str] = None,
) -> ReferenceFilePageDto:
        """
        Operation id: listReferenceFiles
        List project reference files
        
        :param project_uid: str (required), path. 
        :param created_by: Optional[str] = None (optional), query. UID of user.
        :param date_created_since: Optional[str] = None (optional), query. date time in ISO 8601 UTC format.
        :param filename: Optional[str] = None (optional), query. 
        :param order: Optional[str] = "DESC" (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. 
        :param page_size: Optional[int] = 50 (optional), query. 
        :param sort: Optional[str] = "DATE_CREATED" (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ReferenceFilePageDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/references"
        params = {
            "filename": filename,
            "dateCreatedSince": date_created_since,
            "createdBy": created_by,
            "pageNumber": page_number,
            "pageSize": page_size,
            "sort": sort,
            "order": order
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ReferenceFilePageDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from .additional_workflow_step import AdditionalWorkflowStepOperations
from .analysis import AnalysisOperations
from .async_request import AsyncRequestOperations
from .authentication import AuthenticationOperations
from .bilingual_file import BilingualFileOperations
from .business_unit import BusinessUnitOperations
from .buyer import BuyerOperations
from .client import ClientOperations
from .connector import ConnectorOperations
from .cost_center import CostCenterOperations
from .custom_fields import CustomFieldsOperations
from .custom_file_type import CustomFileTypeOperations
from .domain import DomainOperations
from .email_template import EmailTemplateOperations
from .file import FileOperations
from .glossary import GlossaryOperations
from .importsettings import ImportsettingsOperations
from .conversations import ConversationsOperations
from .supported_languages import SupportedLanguagesOperations
from .language_quality_assessment import LanguageQualityAssessmentOperations
from .quality_assurance import QualityAssuranceOperations
from .machine_translation_settings import MachineTranslationSettingsOperations
from .machine_translation import MachineTranslationOperations
from .mapping import MappingOperations
from .language_ai import LanguageAIOperations
from .net_rate_scheme import NetRateSchemeOperations
from .notifications import NotificationsOperations
from .price_list import PriceListOperations
from .project_template import ProjectTemplateOperations
from .term_base import TermBaseOperations
from .translation_memory import TranslationMemoryOperations
from .project import ProjectOperations
from .job import JobOperations
from .translation import TranslationOperations
from .segment import SegmentOperations
from .provider import ProviderOperations
from .project_reference_file import ProjectReferenceFileOperations
from .quote import QuoteOperations
from .scim import SCIMOperations
from .segmentation_rules import SegmentationRulesOperations
from .spell_check import SpellCheckOperations
from .sub_domain import SubDomainOperations
from .user import UserOperations
from .workflow_step import WorkflowStepOperations
from .vendor import VendorOperations
from .webhook import WebhookOperations
from .xml_assistant import XMLAssistantOperations
from .workflowchanges import WorkflowchangesOperations



all = [
    AdditionalWorkflowStepOperations,
    AnalysisOperations,
    AsyncRequestOperations,
    AuthenticationOperations,
    BilingualFileOperations,
    BusinessUnitOperations,
    BuyerOperations,
    ClientOperations,
    ConnectorOperations,
    CostCenterOperations,
    CustomFieldsOperations,
    CustomFileTypeOperations,
    DomainOperations,
    EmailTemplateOperations,
    FileOperations,
    GlossaryOperations,
    ImportsettingsOperations,
    ConversationsOperations,
    SupportedLanguagesOperations,
    LanguageQualityAssessmentOperations,
    QualityAssuranceOperations,
    MachineTranslationSettingsOperations,
    MachineTranslationOperations,
    MappingOperations,
    LanguageAIOperations,
    NetRateSchemeOperations,
    NotificationsOperations,
    PriceListOperations,
    ProjectTemplateOperations,
    TermBaseOperations,
    TranslationMemoryOperations,
    ProjectOperations,
    JobOperations,
    TranslationOperations,
    SegmentOperations,
    ProviderOperations,
    ProjectReferenceFileOperations,
    QuoteOperations,
    SCIMOperations,
    SegmentationRulesOperations,
    SpellCheckOperations,
    SubDomainOperations,
    UserOperations,
    WorkflowStepOperations,
    VendorOperations,
    WebhookOperations,
    XMLAssistantOperations,
    WorkflowchangesOperations
    
]


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    UploadResultDto,
    FileListDto,
    ConnectorDto,
    ConnectorAsyncTaskStatesDto,
    ConnectorListDto,
    InputStreamLength,
    GetFileRequestParamsDto,
    UploadFileV2Meta,
    AsyncFileOpResponseDto
    
)


class ConnectorOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def get_connector(
        self,
        connector_id: str,
        phrase_token: Optional[str] = None,
) -> ConnectorDto:
        """
        Operation id: getConnector
        Get a connector
        
        :param connector_id: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ConnectorDto
        """
        endpoint = f"/api2/v1/connectors/{connector_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ConnectorDto(**r.json())
        


    async def get_connector_async_task_states(
        self,
        project_uid: str,
        date_created_from: Optional[str] = None,
        date_created_to: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 100,
        task_processing_type: Optional[List[str]] = None,
        task_type: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> ConnectorAsyncTaskStatesDto:
        """
        Operation id: getConnectorAsyncTaskStates
        Get Connector async task states.
        
        :param project_uid: str (required), query. Filter by projectUid.
        :param date_created_from: Optional[str] = None (optional), query. Date range from, based on dateCreated.
        :param date_created_to: Optional[str] = None (optional), query. Date range to, based on dateCreated.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 100 (optional), query. Page size, accepts values between 1 and 1000, default 50.
        :param task_processing_type: Optional[List[str]] = None (optional), query. 
        :param task_type: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ConnectorAsyncTaskStatesDto
        """
        endpoint = f"/api2/v1/connectorAsyncTasks"
        params = {
            "projectUid": project_uid,
            "taskType": task_type,
            "taskProcessingType": task_processing_type,
            "dateCreatedFrom": date_created_from,
            "dateCreatedTo": date_created_to,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ConnectorAsyncTaskStatesDto(**r.json())
        


    async def get_connector_list(
        self,
        type: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> ConnectorListDto:
        """
        Operation id: getConnectorList
        List connectors
        
        :param type: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ConnectorListDto
        """
        endpoint = f"/api2/v1/connectors"
        params = {
            "type": type
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ConnectorListDto(**r.json())
        


    async def get_file_for_connector(
        self,
        connector_id: str,
        file: str,
        folder: str,
        phrase_token: Optional[str] = None,
) -> InputStreamLength:
        """
        Operation id: getFileForConnector
        Download file
        Download a file from a subfolder of the selected connector
        :param connector_id: str (required), path. 
        :param file: str (required), path. 
        :param folder: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: InputStreamLength
        """
        endpoint = f"/api2/v1/connectors/{connector_id}/folders/{folder}/files/{file}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return InputStreamLength(**r.json())
        


    async def get_file_for_connector_v2(
        self,
        get_file_request_params_dto: GetFileRequestParamsDto,
        connector_id: str,
        file: str,
        folder: str,
        phrase_token: Optional[str] = None,
) -> AsyncFileOpResponseDto:
        """
        Operation id: getFileForConnectorV2
        Download file (async)
        
Create an asynchronous request to download a file from a (sub)folder of the selected connector. 
After a callback with successful response is received, prepared file can be downloaded by [Download prepared file](#operation/getPreparedFile) 
or [Create job from connector asynchronous download task](#operation/createJobFromAsyncDownloadTask).

        :param get_file_request_params_dto: GetFileRequestParamsDto (required), body. 
        :param connector_id: str (required), path. 
        :param file: str (required), path. 
        :param folder: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AsyncFileOpResponseDto
        """
        endpoint = f"/api2/v2/connectors/{connector_id}/folders/{folder}/files/{file}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = get_file_request_params_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AsyncFileOpResponseDto(**r.json())
        


    async def get_folder(
        self,
        connector_id: str,
        folder: str,
        direction: Optional[str] = "ASCENDING",
        file_type: Optional[str] = "ALL",
        project_uid: Optional[str] = None,
        sort: Optional[str] = "NAME",
        source_locale: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> FileListDto:
        """
        Operation id: getFolder
        List files in a subfolder
        List files in a subfolder of the selected connector
        :param connector_id: str (required), path. 
        :param folder: str (required), path. 
        :param direction: Optional[str] = "ASCENDING" (optional), query. 
        :param file_type: Optional[str] = "ALL" (optional), query. 
        :param project_uid: Optional[str] = None (optional), query. 
        :param sort: Optional[str] = "NAME" (optional), query. 
        :param source_locale: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileListDto
        """
        endpoint = f"/api2/v1/connectors/{connector_id}/folders/{folder}"
        params = {
            "projectUid": project_uid,
            "sourceLocale": source_locale,
            "fileType": file_type,
            "sort": sort,
            "direction": direction
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileListDto(**r.json())
        


    async def get_prepared_file(
        self,
        connector_id: str,
        file: str,
        folder: str,
        task_id: str,
        phrase_token: Optional[str] = None,
) -> InputStreamLength:
        """
        Operation id: getPreparedFile
        Download prepared file
        Download the file by referencing successfully finished async download request [Connector - Download file (async)](#operation/getFile_1).
        :param connector_id: str (required), path. 
        :param file: str (required), path. 
        :param folder: str (required), path. 
        :param task_id: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: InputStreamLength
        """
        endpoint = f"/api2/v2/connectors/{connector_id}/folders/{folder}/files/{file}/tasks/{task_id}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return InputStreamLength(**r.json())
        


    async def get_root_folder(
        self,
        connector_id: str,
        direction: Optional[str] = "ASCENDING",
        file_type: Optional[str] = "ALL",
        project_uid: Optional[str] = None,
        sort: Optional[str] = "NAME",
        source_locale: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> FileListDto:
        """
        Operation id: getRootFolder
        List files in root
        List files in a root folder of the selected connector
        :param connector_id: str (required), path. 
        :param direction: Optional[str] = "ASCENDING" (optional), query. 
        :param file_type: Optional[str] = "ALL" (optional), query. 
        :param project_uid: Optional[str] = None (optional), query. 
        :param sort: Optional[str] = "NAME" (optional), query. 
        :param source_locale: Optional[str] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileListDto
        """
        endpoint = f"/api2/v1/connectors/{connector_id}/folders"
        params = {
            "projectUid": project_uid,
            "sourceLocale": source_locale,
            "fileType": file_type,
            "sort": sort,
            "direction": direction
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileListDto(**r.json())
        


    async def upload_file(
        self,
        connector_id: str,
        file: bytes,
        folder: str,
        content_type: str = "multipart/form-data",
        commit_message: Optional[str] = None,
        mime_type: Optional[str] = None,
        source_file_name: Optional[str] = None,
        subfolder_name: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> UploadResultDto:
        """
        Operation id: uploadFile
        Upload a file to a subfolder of the selected connector
        Upload a file to a subfolder of the selected connector
        :param connector_id: str (required), path. 
        :param file: bytes (required), formData. Translated file to upload.
        :param folder: str (required), path. 
        :param content_type: str = "multipart/form-data" (required), header. 
        :param commit_message: Optional[str] = None (optional), formData. Commit message for upload to Git, etc..
        :param mime_type: Optional[str] = None (optional), formData. Mime type of the file to upload.
        :param source_file_name: Optional[str] = None (optional), formData. Name or ID of the original file.
        :param subfolder_name: Optional[str] = None (optional), formData. Optional subfolder to upload the file to.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UploadResultDto
        """
        endpoint = f"/api2/v1/connectors/{connector_id}/folders/{folder}"
        params = {
            
        }
        headers = {
            "Content-Type": content_type
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UploadResultDto(**r.json())
        


    async def upload_file_v2(
        self,
        memsource: UploadFileV2Meta,
        connector_id: str,
        file: bytes,
        file_name: str,
        folder: str,
        content_type: str = "multipart/form-data",
        mime_type: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> AsyncFileOpResponseDto:
        """
        Operation id: uploadFileV2
        Upload file (async)
        Upload a file to a subfolder of the selected connector
        :param memsource: UploadFileV2Meta (required), header. 
        :param connector_id: str (required), path. 
        :param file: bytes (required), formData. Translated file to upload.
        :param file_name: str (required), path. 
        :param folder: str (required), path. 
        :param content_type: str = "multipart/form-data" (required), header. 
        :param mime_type: Optional[str] = None (optional), query. Mime type of the file to upload.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AsyncFileOpResponseDto
        """
        endpoint = f"/api2/v2/connectors/{connector_id}/folders/{folder}/files/{file_name}/upload"
        params = {
            "mimeType": mime_type
            
        }
        headers = {
            "Memsource": memsource.model_dump_json(),
            "Content-Type": content_type
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AsyncFileOpResponseDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")